@@ -145,9 +145,6 @@ class Renderer:
                                                                 logging.INFO)
             logger.log(level, f"Closing '{self.name}' renderer")
 
-            # Close the root device and all of its renderers.
-            await self.renderers_list.close()
-
             # Handle the race condition where the Renderer.run() task
             # has been created but not yet started.
             if self.nullsink is not None:
@@ -162,9 +159,19 @@ class Renderer:
             if (self.curtask is not None and
                     asyncio.current_task() != self.curtask):
                 self.curtask.cancel()
-            await self.pulse_unregister()
+
             await self.stream_sessions.close_session()
 
+            # Close the root device and all of its renderers.
+            # The pulse module is unregistered in renderers_list.close() to
+            # ensure that it is unregistered before self.root_device is
+            # removed from the control_point.root_devices dictionary. This
+            # avoids a race condition where the upnp device may be registered
+            # again with the same name (i.e. uuid) by pulse following an ssdp
+            # discovery (and therefore causing a crash) while the module is
+            # still registered.
+            await self.renderers_list.close()
+
     def getattr(self, name):
         """Falling back to root device when upn_device attribute missing."""
         try:
@@ -172,26 +179,6 @@ class Renderer:
         except AttributeError:
             return getattr(self.root_device, name)
 
-    async def disable_for(self, *, period):
-        """Disable the renderer for 'period' seconds."""
-
-        # Unload the null-sink module, sleep 'period' seconds and load a new
-        # module. During  the sleep period, the stream that was routed to this
-        # null-sink is routed to the default sink instead of being silently
-        # discarded by the null-sink. After loading the new null-sink module,
-        # the renderer receives a 'change' pulse event and starts a new stream
-        # session.
-        await self.pulse_unregister()
-
-        if period:
-            logger.info(f'Wait {period} seconds before'
-                        f' re-enabling {self.name}')
-            await asyncio.sleep(period)
-
-        if not await self.pulse_register():
-            logger.error(f'Cannot load new null-sink module for {self.name}')
-            await self.close()
-
     async def disable_root_device(self):
         """Close the renderer and disable its root device."""
 
@@ -558,13 +545,11 @@ class Renderer:
             test_end = self.control_point.test_end
             while test_end is None or not test_end.done():
                 await self.handle_pulse_event()
-            await self.close()
 
         except asyncio.CancelledError:
             pass
         except UPnPSoapFaultError as e:
             logger.error(f'{e!r}')
-            await self.disable_root_device()
         except (OSError, UPnPClosedDeviceError, ControlPointAbortError) as e:
             logger.error(f'{e!r}')
         except Exception:
@@ -649,6 +634,7 @@ class RenderersList(UserList):
             for renderer in self.data:
                 try:
                     await renderer.close()
+                    await renderer.pulse_unregister()
                 except Exception as e:
                     logger.error(f'Got exception closing {renderer.name}:'
                                  f' {e!r}')
@@ -716,6 +702,8 @@ class AVControlPoint(UPnPApplication):
     def abort(self, msg):
         """Abort the whole program from a non-main task."""
 
+        # Should be called instead of 'assert False' when there is a
+        # programatic error.
         self.cp_tasks.create_task(self.close(msg), name='abort')
         raise ControlPointAbortError(msg)
 
